// ----------------------------------------------------------------------------
// Copyright (C) 2014
//              David Freese, W1HKJ
//
// This file is part of fldigi
//
// fldigi is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 3 of the License, or
// (at your option) any later version.
//
// fldigi is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program.  If not, see <http://www.gnu.org/licenses/>.
// ----------------------------------------------------------------------------

#ifndef NETWORK_H_
#define NETWORK_H_

#include <string>

bool network_query(const std::string& node, const std::string& service,
		   const std::string& request, std::string& reply, double timeout = 0.0);
bool fetch_http(const std::string& url, std::string& reply, double timeout = 0.0);
bool fetch_http_gui(const std::string& url, std::string& reply, double timeout = 0.0);
bool fetch_http_gui(const std::string& url, std::string& reply, double timeout,
		    void(*busy)(void*), void* arg1, void(*done)(void*), void* arg2);

#endif // NETWORK_H_
